<?php # $Id: serendipity_lang_da.inc.php 2575 2009-08-24 08:24:19Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) by Tom Sommer, <ts@dreamcoder.dk>
# Thanks to: Jeppe Lund, <nocture@nocture.dk>
#            Robert Piil, <robert@piil.org>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-1');
@define('SQL_CHARSET', 'latin1');
@define('DATE_LOCALES', 'da_DK.ISO8859-1, da_DK.ISO-8859-1, danish, da, da_DK');
@define('DATE_FORMAT_ENTRY', '%A d. %e. %B %Y');
@define('DATE_FORMAT_SHORT', '%d.%m.%Y %H:%M');
@define('WYSIWYG_LANG', 'da');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Serendipity Administrationssuite');
@define('HAVE_TO_BE_LOGGED_ON', 'Du skal vre logget ind for at kunne se denne side');
@define('WRONG_USERNAME_OR_PASSWORD', 'Du har indtastet et forkert brugernavn eller adgangskode');
@define('APPEARANCE', 'Udseende');
@define('MANAGE_STYLES', 'Administrer skabeloner');
@define('CONFIGURE_PLUGINS', 'Konfigurerer plugins');
@define('CONFIGURATION', 'Konfiguration');
@define('BACK_TO_BLOG', 'Tilbage til weblog');
@define('LOGIN', 'Login');
@define('LOGOUT', 'Log ud');
@define('LOGGEDOUT', 'Logget ud.');
@define('CREATE', 'Opret');
@define('SAVE', 'Gem');
@define('NAME', 'Navn');
@define('CREATE_NEW_CAT', 'Opret ny kategori');
@define('I_WANT_THUMB', 'Jeg vil bruge minibilledet i min artikel.');
@define('I_WANT_BIG_IMAGE', 'Jeg vil bruge det originale billede i min artikel.');
@define('I_WANT_NO_LINK', 'Vis billedet uden link');
@define('I_WANT_IT_TO_LINK', 'Vis billedet med link');
@define('BACK', 'Tilbage');
@define('FORWARD', 'Fremad');
@define('ANONYMOUS', 'Annonym');
@define('NEW_TRACKBACK_TO', 'Ny trackback lavet til');
@define('NEW_COMMENT_TO', 'Ny kommentar lavet til');
@define('RECENT', 'Nyere...');
@define('OLDER', 'ldre...');
@define('DONE', 'Frdig');
@define('WELCOME_BACK', 'Velkommen tilbage,');
@define('TITLE', 'Titel');
@define('DESCRIPTION', 'Beskrivelse');
@define('PLACEMENT', 'Placering');
@define('DELETE', 'Slet');
@define('UP', 'OP');
@define('DOWN', 'NED');
@define('ENTRIES', 'artikler');
@define('NEW_ENTRY', 'Ny artikel');
@define('EDIT_ENTRIES', 'Rediger artikler');
@define('CATEGORIES', 'Kategorier');
@define('WARNING_THIS_BLAHBLAH', "ADVARSEL:\\nDette kan tage lang tid hvis der er mange billeder uden minibilleder.");
@define('CREATE_THUMBS', 'Genopbyg minibilleder');
@define('MANAGE_IMAGES', 'Administrer billeder');
@define('NAME', 'Navn');
@define('EMAIL', 'Email');
@define('HOMEPAGE', 'Hjemmeside');
@define('COMMENT', 'Kommentar');
@define('REMEMBER_INFO', 'Husk oplysninger?');
@define('SUBMIT_COMMENT', 'Tilfj kommentar');
@define('NO_ENTRIES_TO_PRINT', 'Der er ingen artikler at vise');
@define('COMMENTS', 'Kommentarer');
@define('ADD_COMMENT', 'Tilfj kommentar');
@define('NO_COMMENTS', 'Ingen kommentarer');
@define('POSTED_BY', 'Skrevet af');
@define('ON', 'aktiv');
@define('A_NEW_COMMENT_BLAHBLAH', 'En ny kommentar er blevet oprettet p din blog "%s", til artiklen ved navn "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Et nyt trackback er blevet lavet til din artikel ved navn "%s".');
@define('NO_CATEGORY', 'Ingen kategori');
@define('ENTRY_BODY', 'Artikel indhold');
@define('EXTENDED_BODY', 'Udvidet indhold');
@define('CATEGORY', 'Kategori');
@define('EDIT', 'Rediger');
@define('NO_ENTRIES_BLAHBLAH', 'Ingen artikler blev fundet som indeholdt %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Din sgning p %s returnerede %s resultater:');
@define('IMAGE', 'Billede');
@define('ERROR_FILE_NOT_EXISTS', 'Fejl: Det gamle filnavn findes ikke!');
@define('ERROR_FILE_EXISTS', 'Fejl: Det nye filnavn eksisterer allerede, vlg et andet!');
@define('ERROR_SOMETHING', 'Fejl: Der gik noget galt');
@define('ADDING_IMAGE', 'Tilfjet billede...');
@define('THUMB_CREATED_DONE', 'Minibillede er oprettet.<br>Done.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Fejl: Filen findes allerede p din maskine!');
@define('GO', 'Begynd!');
@define('NEWSIZE', 'Ny strrelse: ');
@define('RESIZE_BLAHBLAH', '<b>ndre strrelse p %s</b>');
@define('ORIGINAL_SIZE', 'Original strrelse: <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Her kan du justere billedets strrelse. Hvis du vil bevare proportionerne, skal du bare indtaste n af vrdirene og trykke p TAB-tasten, den anden vrdi beregnes s automatisk:');
@define('QUICKJUMP_CALENDAR', 'Hurtigkalender');
@define('QUICKSEARCH', 'Sgning');
@define('SEARCH_FOR_ENTRY', 'Sg efter en artikel');
@define('ARCHIVES', 'Arkiver');
@define('BROWSE_ARCHIVES', 'Gennemse arkiver efter mneder');
@define('TOP_REFERRER', 'Referencer');
@define('SHOWS_TOP_SITES', 'Viser de sites som oftest linker til din blog');
@define('TOP_EXITS', 'Udgangssider');
@define('SHOWS_TOP_EXIT', 'Viser de udgangssider der er klikket flest gange p');
@define('SYNDICATION', 'Syndikering');
@define('SHOWS_RSS_BLAHBLAH', 'Viser RSS syndikeringslinks');
@define('ADVERTISES_BLAHBLAH', 'Reklamer for din blogs oprindelse');
@define('HTML_NUGGET', 'HTML Nugget');
@define('HOLDS_A_BLAHBLAH', 'Indeholder et stykke HTML i din sidebar');
@define('TITLE_FOR_NUGGET', 'Titel p din nugget');
@define('THE_NUGGET', 'HTML-indholdet af din nugget');
@define('SYNDICATE_THIS_BLOG', 'Syndiker denne blog');
@define('YOU_CHOSE', 'Du valgte %s');
@define('IMAGE_SIZE', 'Billedestrrelse');
@define('IMAGE_AS_A_LINK', 'Billedeindsttelse');
@define('POWERED_BY', 'Drives af');
@define('TRACKBACKS', 'Trackbacks');
@define('TRACKBACK', 'Trackback');
@define('NO_TRACKBACKS', 'Ingen Trackbacks');
@define('TOPICS_OF', 'Emner af');
@define('VIEW_FULL', 'Vis i fuld');
@define('VIEW_TOPICS', 'Vis emner');
@define('AT', 'kl');
@define('SET_AS_TEMPLATE', 'St som skabelon');
@define('IN', 'i');
@define('EXCERPT', 'Uddrag');
@define('TRACKED', 'Tracked');
@define('LINK_TO_ENTRY', 'Link til artikel');
@define('LINK_TO_REMOTE_ENTRY', 'Link til ekstern artikel');
@define('IP_ADDRESS', 'IP-adresse');
@define('USER', 'Bruger');
@define('THUMBNAIL_USING_OWN', 'Bruger %s som dets eget minibillede, fordi det allerede er s lille.');
@define('THUMBNAIL_FAILED_COPY', 'Ville gerne have brugt %s som dets egen minibillede, men kunne ikke kopiere!');
@define('AUTHOR', 'Forfatter');
@define('LAST_UPDATED', 'Sidst opdateret');
@define('TRACKBACK_SPECIFIC', 'Trackback URI til denne artikel');
@define('DIRECT_LINK', 'Direkte link til denne artikel');
@define('COMMENT_ADDED', 'Din kommentar blev tilfjet. ');
@define('COMMENT_ADDED_CLICK', 'Klik %her for at g tilbage%s til kommentarerne, og %sher for at lukke%s dette vindue.');
@define('COMMENT_NOT_ADDED_CLICK', 'Klik %sher for at g tilbage%s til kommentarene, og %sher for at lukke%s dette vindue. ');
@define('COMMENTS_DISABLE', 'Tillad ikke kommentarer til denne artikel');
@define('COMMENTS_ENABLE', 'Tillad kommentarer til denne artikel');
@define('COMMENTS_CLOSED', 'Forfatteren har valgt ikke at tillade kommentarer til denne artikel');
@define('EMPTY_COMMENT', 'Din kommentar indeholdt ikke noget, g venligst %stilbage%s og prv igen');
@define('ENTRIES_FOR', 'Artikler fra %s');
@define('DOCUMENT_NOT_FOUND', 'Dokumentet %s kunne ikke findes.');
@define('USERNAME', 'Brugernavn');
@define('PASSWORD', 'Adgangskode');
@define('AUTOMATIC_LOGIN', 'Gem oplysningerne');
@define('SERENDIPITY_INSTALLATION', 'Serendipity installation');
@define('LEFT', 'venstre');
@define('RIGHT', 'hjre');
@define('HIDDEN', 'skjult');
@define('REMOVE_TICKED_PLUGINS', 'Fjern valgte plugins');
@define('SAVE_CHANGES_TO_LAYOUT', 'Gem layout-ndringerne');
@define('COMMENTS_FROM', 'Kommentar fra');
@define('ERROR', 'Fejl');
@define('ENTRY_SAVED', 'Din artikel blev gemt');
@define('DELETE_SURE', 'Er du sikker p du vil slette #%s permanent?');
@define('NOT_REALLY', 'Egentlig ikke...');
@define('DUMP_IT', 'Smid den ud!');
@define('RIP_ENTRY', 'Farvel artikel #%s');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Kategori #%s blev slettet. Gamle artikler flyttet til kategori #%s');
@define('CATEGORY_DELETED', 'Kategori #%s blev slettet.');
@define('INVALID_CATEGORY', 'Ingen kategori blev valgt til sletning');
@define('CATEGORY_SAVED', 'Kategori gemt');
@define('SELECT_TEMPLATE', 'Vlg den skabelon du nsker at bruge til din blog');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Der var problemer under indsttelsen af artiklerne!');
@define('YES', 'Ja');
@define('NO', 'Nej');
@define('USE_DEFAULT', 'Default');
@define('CHECK_N_SAVE', 'Check &amp; gem');
@define('DIRECTORY_WRITE_ERROR', 'Kan ikke skrive til biblioteket %s. Check filrettighederne.');
@define('DIRECTORY_CREATE_ERROR', 'Biblioteket %s eksisterer ikke og kunne ikke oprettes. Opret venligst biblioteket manuelt');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; Kr <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Kan ikke eksekvere %s');
@define('FILE_WRITE_ERROR', 'Kan ikke skrive til filen %s.');
@define('FILE_CREATE_YOURSELF', 'Opret venligst filen selv og check dens rettigheder');
@define('COPY_CODE_BELOW', '<br />* Kopier blot koden nedenunder og placer den i %s i din %s mappe:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'ndr www til den bruger som apache krer som (fx. nobody).');
@define('BROWSER_RELOAD', 'Nr du har gjort dette, s tryk p browserens "opdater" knap');
@define('DIAGNOSTIC_ERROR', 'Vi har opdaget nogle fejl mens vi krte nogle diagnostiker p dine indtastede informationer:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity er endnu ikke installeret. Klik <a href="%s">her for at installere</a> nu.');
@define('INCLUDE_ERROR', 'serendipityfejl: Kunne ikke inkludere %s - Afbryder.');
@define('DATABASE_ERROR', 'serendipityfejl: Kunne ikke oprette forbindelse til databasen - Afbryder.');
@define('CREATE_DATABASE', 'Opretter standarddatabase setup...');
@define('ATTEMPT_WRITE_FILE', 'Forsger at skrive til %s ...');
@define('WRITTEN_N_SAVED', 'Konfiguration skrevet &amp; gemt');
@define('IMAGE_ALIGNMENT', 'Billedejustering');
@define('ENTER_NEW_NAME', 'Indtast det nye navn for: ');
@define('RESIZING', 'ndre dimensioner');
@define('RESIZE_DONE', 'Frdig (ndrede %s billeder).');
@define('SYNCING', 'Synkroniserer databasen med billedemappen');
@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
@define('SYNC_DONE', 'Frdig (Synkroniserede %s billeder).');
@define('DELETE_IMAGE_FAIL' , 'Kunne ikke slette billedet <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Slettede billedet ved navn <b>%s</b>');
@define('FILE_NOT_FOUND', 'Kunne ikke finde filen ved navn <b>%s</b>, mske er den allerede slettet?');
@define('ABORT_NOW', 'Afbryd nu');
@define('REMOTE_FILE_NOT_FOUND', 'Filen kunne ikke findes p serveren, er du sikker p URLen: <b>%s</b> er korrekt?');
@define('FILE_FETCHED', '%s hentet: %s');
@define('FILE_UPLOADED', 'Filen %s er blevet uploadet: %s');
@define('WORD_OR', 'eller');
@define('SCALING_IMAGE', 'ndre strrelsen p %s til %s x %s px');
@define('KEEP_PROPORTIONS', 'Bevar forholdet');
@define('REALLY_SCALE_IMAGE', 'Er du sikker p du vil ndre strrelsen p dette billede? Der er ingen vej tilbage!');
@define('TOGGLE_ALL', 'Vis/Skjul alle');
@define('TOGGLE_OPTION', 'Vis/Skjul denne option');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Abonnr p denne artikel');
@define('UNSUBSCRIBE_OK', "%s er ikke lngere abonnement p denne artikel");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Ny kommentar p abonnerede artikel "%s"');
@define('SUBSCRIPTION_MAIL', "Hej %s,\n\nEn ny kommentar er blevet lavet til en artikel du abonnerer p hos \"%s\", ved navn \"%s\"\nNavnet p skribenten er: %s\n\nDu kan finde artiklen her: %s\n\nDu kan stoppe dit abonnement ved at klikke p dette link: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Hej %s,\n\nEt nyt trackback er blevet lavet til en artikel du abonnerer p hos \"%s\", ved navn \"%s\"\nNavnet p skribenten er: %s\n\nDu kan finde artiklen her: %s\n\nDu kan stoppe dit abonnement ved at klikke p dette link: %s\n");
@define('SIGNATURE', "\n-- \n%s bruger Serendipity.\nDen bedste blog p nettet, du kan ogs bruge den.\nKig nrmere p <http://s9y.org> for at finde mere information.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 kommentarer');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Feltet "Hovedredaktr"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Feltet "webmaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Billede til RSS feedet');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Billedebredde');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Billedehjde');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'Email adressen p webmasteren, hvis tilgngelig. (tom: skjult) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'E-mail adressen p redaktren, hvis tilgngelig. (tom: skjult) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL p et billede i GIF/JPEG/PNG format, hvis tilgngeligt. (tom: serendipity-logo)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'i pixels, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'i pixels, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Feltet "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Antallet af minutter din blog skal gemmes af eksterne sider/programmer (tom: skjult) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Feltet "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Skal "pubDate"-feltet vre indkapslet til en RSS-channel, for at vise datoen p den nyeste artikel?');
@define('CONTENT', 'Indhold');
@define('TYPE', 'Type');
@define('DRAFT', 'Udkast');
@define('PUBLISH', 'Udgiv');
@define('PREVIEW', 'Vis');
@define('DATE', 'Dato');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Advarsel: Den dato du indtastede var ugyldig. Det skal indtastes i flgende format: YYYY-MM-DD HH:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Viser listen over kategorier.');
@define('ALL_AUTHORS', 'Alle forfattere');
@define('CATEGORIES_TO_FETCH', 'Kategorier som skal hentes');
@define('CATEGORIES_TO_FETCH_DESC', 'Hent kategorier fra en bestemt forfatter?');
@define('PAGE_BROWSE_ENTRIES', 'Side %s af %s, i alt %s artikler');
@define('PREVIOUS_PAGE', 'forrige side');
@define('NEXT_PAGE', 'nste side');
@define('ALL_CATEGORIES', 'Alle kategorier');
@define('DO_MARKUP', 'Udfrt Markup-transformation');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Datoformat');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formatet p artiklens faktiske dato, brug PHPs strftime() variabler. (Standard: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Kunne ikke bne skabelonen, opdater Serendipity!');
@define('ADVANCED_OPTIONS', 'Avancerede indstillinger');
@define('EDIT_ENTRY', 'Rediger artikel');
@define('HTACCESS_ERROR', 'For at kunne checke din lokale webserver\'s installation, skal Serendipity vre i stand til at skrive til filen ".htaccess". Dette var ikke muligt pga. forkerte rettigheder. Justr rettighederne sledes: <br />&nbsp;&nbsp;%s<br />og genindls siden.');
@define('SORT_ORDER', 'Sorter efter');
@define('SORT_ORDER_NAME', 'Filnavn');
@define('SORT_ORDER_EXTENSION', 'Filtype');
@define('SORT_ORDER_SIZE', 'Filstrrelse');
@define('SORT_ORDER_WIDTH', 'Billedebrede');
@define('SORT_ORDER_HEIGHT', 'Billedehjde');
@define('SORT_ORDER_DATE', 'Upload-dato');
@define('SORT_ORDER_ASC', 'Stigende');
@define('SORT_ORDER_DESC', 'Faldende');
@define('THUMBNAIL_SHORT', 'Mini');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Formater %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Starten p ugen');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity har opdaget at din nuvrende konfiguration passer til version %s. Serendipity selv er installeret som version %s, Det er ndvendigt at opgradere! <a href="%s">Klik her!</a>');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Velkommen til Serendipitys opgraderingsscript.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Scriptet vil hjlpe dig med at opgradere Serendipity %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'Denne meddelelse vises, fordi Serendipity er installeret med version %s, men databasen er endnu ikke opgraderet til denne version.');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Database opdateringer (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Flgende .sql-filer skal eksekveres fr Serendipity igen kan fungere normalt.');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Versionsspecifikke opgaver');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Ingen versionsspecifikke opgaver fundet');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'nsker du at ovenstende opgaver udfres?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Nej, jeg udfrer dem manuelt');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Ja tak!');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Det ser ud til at opgradering ikke er ndvendig.');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity er opgraderet');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Du har ignoreret en del af opgraderingen. Undersg venligst om databasen er korrekt opdateret, og planlagte opgaver udfrt');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Din Serendipity-installation er nu opgraderet til version %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Du kan vende tilbage til din blog ved at klikke %sher%s');
@define('MANAGE_USERS', 'Hndter brugerer');
@define('CREATE_NEW_USER', 'Opret by bruger');
@define('CREATE_NOT_AUTHORIZED', 'Du kan ikke redigere brugere med den samme brugerniveau som digselv');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Du kan ikke oprette brugere med en hjere brugerniveau end digselv');
@define('CREATED_USER', 'En ny bruger %s er blevet oprettet');
@define('MODIFIED_USER', 'Egenskaberne for brugeren %s er blevet ndret');
@define('USER_LEVEL', 'brugerniveau');
@define('DELETE_USER', 'Du er ved at slette bruger #%d %s. Er du sikker? Dette vil forhindre visning af alle artikler skrevet af ham.');
@define('DELETED_USER', 'Bruger #%d %s er blevet slettet.');
@define('LIMIT_TO_NUMBER', 'Hvor mange punkter skal vises?');
@define('ENTRIES_PER_PAGE', 'artikler per side');
@define('PERMISSIONS', 'Rettigheder');
@define('INTEGRITY', 'Verify Installation Integrity');
@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
@define('CHECKSUMS_PASS', 'All required files verified.');
@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Database indstillinger');
@define('INSTALL_CAT_DB_DESC', 'Her kan du indtaste dine database indstillinger');
@define('INSTALL_DBTYPE', 'Database type');
@define('INSTALL_DBTYPE_DESC', 'Database type');
@define('INSTALL_DBHOST', 'Database host');
@define('INSTALL_DBHOST_DESC', 'Hostnavn til din database server');
@define('INSTALL_DBUSER', 'Database bruger');
@define('INSTALL_DBUSER_DESC', 'Brugernavnet der er brugt til at forbinde til din database');
@define('INSTALL_DBPASS', 'Database adgangskode');
@define('INSTALL_DBPASS_DESC', 'Adgangskoden der passer til ovenstende brugernavn');
@define('INSTALL_DBNAME', 'Database navn');
@define('INSTALL_DBNAME_DESC', 'Navnet p din database');
@define('INSTALL_DBPREFIX', 'Database tabel prfix');
@define('INSTALL_DBPREFIX_DESC', 'Prfix p tabelnavne, fx. serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Stier');
@define('INSTALL_CAT_PATHS_DESC', 'Forskellige stier til forskellige essentielle mapper og filer. Glem ikke efterflgende slashes p biblioteker!');
@define('INSTALL_FULLPATH', 'Fuld sti');
@define('INSTALL_FULLPATH_DESC', 'Den absolutte sti til din serendipity installation');
@define('INSTALL_UPLOADPATH', 'Upload sti');
@define('INSTALL_UPLOADPATH_DESC', 'Alle uploads bliver placeret her, relativ til \'Fuld sti\' - typisk \'uploads/\'');
@define('INSTALL_RELPATH', 'Relativ sti');
@define('INSTALL_RELPATH_DESC', 'Sti til Serendipity i henhold til din browser, typisk \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Relativ skabelon sti');
@define('INSTALL_RELTEMPLPATH_DESC', 'Stien til mappen der indeholder dine skabeloner - Relativ til \'Relativ sti\'');
@define('INSTALL_RELUPLOADPATH', 'Relativ upload sti');
@define('INSTALL_RELUPLOADPATH_DESC', 'Sti til dine uploads i henhold til din browser - Relativ til \'Relativ sti\'');
@define('INSTALL_URL', 'URL til din blog');
@define('INSTALL_URL_DESC', 'Grund URL for din Serendipity installation');
@define('INSTALL_INDEXFILE', 'Index fil');
@define('INSTALL_INDEXFILE_DESC', 'Navnet p din Serendipity index fil');

/* Generel settings */
@define('INSTALL_CAT_SETTINGS', 'Generelle indstillinger');
@define('INSTALL_CAT_SETTINGS_DESC', 'Tilpas den mde Serendipity opfrer sig p');
@define('INSTALL_USERNAME', 'Admin brugernavn');
@define('INSTALL_USERNAME_DESC', 'Brugernavn til admin login');
@define('INSTALL_PASSWORD', 'Admin adgangskode');
@define('INSTALL_PASSWORD_DESC', 'Adgangskode til admin login');
@define('INSTALL_EMAIL', 'Admin email');
@define('INSTALL_EMAIL_DESC', 'E-mail adresse p ejeren af bloggen');
@define('INSTALL_SENDMAIL', 'Send mails til admin?');
@define('INSTALL_SENDMAIL_DESC', 'Vil du modtage emails nr kommentare er givet p dine artikler?');
@define('INSTALL_SUBSCRIBE', 'Tillad brugere at abonnere p artikler?');
@define('INSTALL_SUBSCRIBE_DESC', 'Tillad brugere at abonnere p en artikel og derved modtage en mail nr der bliver oprettet nye kommentare p den artikel');
@define('INSTALL_BLOGNAME', 'Navn p blog');
@define('INSTALL_BLOGNAME_DESC', 'Titlen p din blog');
@define('INSTALL_BLOGDESC', 'Blog beskrivelse');
@define('INSTALL_BLOGDESC_DESC', 'Beskrivelse af din blog');
@define('INSTALL_LANG', 'Sprog');
@define('INSTALL_LANG_DESC', 'Vlg sproget p din blog');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', 'Udseende og indstillinger');
@define('INSTALL_CAT_DISPLAY_DESC', 'Tilpas hvordan Serendipity ser ud og fles');
@define('INSTALL_WYSIWYG', 'Brug WYSIWYG editor');
@define('INSTALL_WYSIWYG_DESC', 'Vil du benytte WYSIWYG editoren? (Virker med IE5+, delvis i Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Gennemtving XHTML 1.1');
@define('INSTALL_XHTML11_DESC', 'nsker du at gennemtvinge XHTML 1.1 overholdelse (Kan skabe problemer i 4. generations browsere)');
@define('INSTALL_POPUP', 'Aktiver brug af popup vinduer');
@define('INSTALL_POPUP_DESC', 'Vil du bne kommentarer og trackbacks i et popup vindue?');
@define('INSTALL_EMBED', 'Er Serendipity embedded?');
@define('INSTALL_EMBED_DESC', 'Hvis du nsker at indkapsle Serendipity inde i en normal side, aktiver da dette direktiv for at ignorere headers og kun udskrive indholdet. Du kan benytte indexFile direktivet til at lave en wrapper fil hvor du placere din normale hjemmeside headers. Konsulter README filen for mere information!');
@define('INSTALL_TOP_AS_LINKS', 'Vis top udgangssider/referencer som links?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"Nej": Udgangs- og henvisende sider er vist som ren tekst for at undg google spam. "Ja": Udgangs- og henvisende sider er vist som hyperlinks. "standard": Brug indstillinger fra global konfiguration (anbefalet).');
@define('INSTALL_BLOCKREF', 'Bloker referencer');
@define('INSTALL_BLOCKREF_DESC', 'Er der nogle specielle hosts du ikke nsker skal vises i reference listen? Separer listen af hostnavne med \';\' og bemrk at disse er blokere med substring masker!');
@define('INSTALL_REWRITE', 'URL Omskrivning');
@define('INSTALL_REWRITE_DESC', 'Vlg hvilken regel du nsker at bruge nr du generere URL\'er. Aktivering af omskrivningsregler vil gre dine URL\'er flotte og gre din side bedre at indeksere for robotter som google. Webserveren skal enten understtte mod_rewrite eller "AllowOverride All" for dit Serendipity bibliotek. Standardindstillingen er automatisk beregnet');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'Billedekonverterings indstillinger');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Generel information om hvordan Serendipity skal hndtere billeder');
@define('INSTALL_IMAGEMAGICK', 'Brug Imagemagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Har du image magick installeret og nsker at bruge det til at ndre strrelse p billeder?');
@define('INSTALL_IMAGEMAGICKPATH', 'Sti til convert binr fil');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Fuld sti og navn p din image magick convert binr fil');
@define('INSTALL_THUMBSUFFIX', 'Thumbnail suffiks');
@define('INSTALL_THUMBSUFFIX_DESC', 'Thumbnails vil blive navngivet i flgende format: original.[suffix].ext');
@define('INSTALL_THUMBWIDTH', 'Thumbnail dimensioner');
@define('INSTALL_THUMBWIDTH_DESC', 'Statisk maximal brede p et auto-genereret thumbnail');
@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
@define('INSTALL_THUMBDIM_WIDTH', 'Width');
@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
    '" only limit the chosen dimension, so the other could be larger than the max size.');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Dine personlige detaljer');
@define('USERCONF_CAT_PERSONAL_DESC', 'ndre dine personlige detaljer');
@define('USERCONF_USERNAME', 'Dit brugernavn');
@define('USERCONF_USERNAME_DESC', 'Brugernavnet du vil bruge for at logge ind i bloggen');
@define('USERCONF_PASSWORD', 'Dit kodeord');
@define('USERCONF_PASSWORD_DESC', 'Kodeordet du vil bruge for at logge ind i bloggen');
@define('USERCONF_EMAIL', 'Din email adresse');
@define('USERCONF_EMAIL_DESC', 'Din personlige email adresse');
@define('USERCONF_SENDCOMMENTS', 'Send beskeder om nye kommentarer?');
@define('USERCONF_SENDCOMMENTS_DESC', 'nsker du at modtage en mail nr nye kommentarer bliver lavet p dine artikler?');
@define('USERCONF_SENDTRACKBACKS', 'Send beskeder om nye trackbacks?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'nsker du at modtage en mail nr nye trackbacks bliver lavet p dine artikler?');
@define('USERCONF_ALLOWPUBLISH', 'Tilladelse: Udgiv artikler?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Kan denne bruger udgive artikler?');

@define('DIRECTORIES_AVAILABLE', 'I listen over tilgngelige undermapper, kan du klikke p en ny mappe for at oprette en ny mappe inden for den stuktur.');
@define('ALL_DIRECTORIES', 'alle mapper');
@define('MANAGE_DIRECTORIES', 'Hndtr mapper');
@define('DIRECTORY_CREATED', 'Mappen <strong>%s</strong> er blevet oprettet.');
@define('PARENT_DIRECTORY', 'Hovedmappe');
@define('CONFIRM_DELETE_DIRECTORY', 'Er du sikker p du vil slette al indholdet af mappen %s?');
@define('ERROR_NO_DIRECTORY', 'Fejl: Mappen %s eksistere ikke');
@define('CHECKING_DIRECTORY', 'Checker filer i mappen %s');
@define('DELETING_FILE', 'Sletter fil %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Kunne ikke fjerne en ikke-tom mappe. Afkryds "gennemtving sletning" feltet, hvis du vil slette disse og tryk derefter p submit igen. Eksisterende filer er:');
@define('DIRECTORY_DELETE_FAILED', 'Sletning af mappe %s mislykkedes. Check rettigheder eller ovenstende beskeder.');
@define('DIRECTORY_DELETE_SUCCESS', 'Mappen %s er blevet slettet.');
@define('SKIPPING_FILE_EXTENSION', 'Ignorerede filen: Manglende filtype %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Ignorere fil: %s er ikke lsbar.');
@define('FOUND_FILE', 'Fandt ny/ndret fil: %s.');
@define('ALREADY_SUBCATEGORY', '%s er allerede en underkategori af %s.');
@define('PARENT_CATEGORY', 'Overkategori');
@define('IN_REPLY_TO', 'Som svar p');
@define('TOP_LEVEL', 'Topniveau');
@define('XML_IMAGE_TO_DISPLAY', 'XML knap');
@define('XML_IMAGE_TO_DISPLAY_DESC','Links til XML Feeds vil blive vist med dette billede. Efterlad tomt for standard, indtast \'none\' for at deaktivere.');
@define('SUCCESS', 'Succes');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '.');
@define('POWERED_BY_SHOW_TEXT', 'Vis "Serendipity" som tekst');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Vil vise "Serendipity Weblog" som tekst');
@define('POWERED_BY_SHOW_IMAGE', 'Vis "Serendipity"" som et logo');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Vis Serendipity logoet');
@define('SETTINGS_SAVED_AT', 'De nye indstillinger er blevet gemt kl %s');
@define('PLUGIN_ITEM_DISPLAY', 'Hvor skal enheden vises?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Kun udvidet artikel');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Kun i oversigten');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Hele tiden');
@define('RSS_IMPORT_CATEGORY', 'Brug denne kategori for kategorilse artikler');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Der skete en ukendt fejl, filen blev ikke uploaded. Mske er din filstrrelse strre end den maximale strrelse tilladt af din serveropstning. Sprg din webudbyder eller rediger din php.ini fil for at tillade uploads af strre filer.');
@define('COMMENTS_WILL_BE_MODERATED', 'Kommentarer til denne artikel skal modereres fr de vil blive vist.');
@define('YOU_HAVE_THESE_OPTIONS', 'Du har flgende muligheder:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Advarsel: Denne kommentar krver godkendelse frend den vil blive vist');
@define('DELETE_COMMENT', 'Slet kommentar');
@define('APPROVE_COMMENT', 'Godkend kommentar');
@define('REQUIRES_REVIEW', 'Krver godkendelse');
@define('COMMENT_APPROVED', 'Kommentar #%s er blevet godkendt');
@define('COMMENT_DELETED', 'Kommentar #%s er blevet slettet');
@define('VIEW', 'Vis');
@define('COMMENT_ALREADY_APPROVED', 'Kommentar #%s ser allerede ud til at vre godkendt');
@define('COMMENT_EDITED', 'Den valgte kommentar er blevet redigeret');
@define('HIDE', 'Skjul');
@define('VIEW_EXTENDED_ENTRY', 'Ls resten af "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Dette link er ikke ikke til at blive klikket. Det indeholder denne artikels trackback URI. Du kan bruge denne URI til at sende ping- & trackbacks fra din egen blog til denne artikel. For at kopiere linket, kan du hjreklikke og vlge "Kopier genvej" i Internet Explorer eller "Copy Link Location" i Mozilla.');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Advarsel: Dette trackback krver godkendelse frend det vil blive vist');
@define('DELETE_TRACKBACK', 'Slet trackback');
@define('APPROVE_TRACKBACK', 'Godkend trackback');
@define('TRACKBACK_APPROVED', 'Trackback #%s er blevet godkendt');
@define('TRACKBACK_DELETED', 'Trackback #%s er blevet slettet');
@define('COMMENTS_MODERATE', 'Kommentarer og trackbacks til denne artikel krver moderering');
@define('PLUGIN_SUPERUSER_HTTPS', 'Brug https til login');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Lader loginlinket pege p en https-destination. Din webserver skal understtte dette!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Gr eksterne links klikbare?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"nej": Eksterne links (Top udgangsider, Top henvisninger, bruger kommentarer) er ikke vist/vist som ren tekst hvor brugbart, for at forhindre google spam (anbefales). "ja": Eksterne links er vist som hyperlinks. Kan overskrives inde i hver enkel sidebar plugin konfigurationen!');
@define('PAGE_BROWSE_COMMENTS', 'Side %s af %s, i alt %s kommentarer');
@define('FILTERS', 'Filtrer');
@define('FIND_ENTRIES', 'Find artikler');
@define('FIND_COMMENTS', 'Find kommentarer');
@define('FIND_MEDIA', 'Find media');
@define('FILTER_DIRECTORY', 'Bibliotek');
@define('SORT_BY', 'Sorter efter');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Intet trackback sendt: Kunne ikke bne forbindelse til %s p port %d');
@define('MEDIA', 'Media');
@define('MEDIA_LIBRARY', 'Mediabibliotek');
@define('ADD_MEDIA', 'Tilfj media');
@define('ENTER_MEDIA_URL', 'Indtast en URL til filen du vil hente');
@define('ENTER_MEDIA_UPLOAD', 'Vlg en fil du nsker at uploade:');
@define('SAVE_FILE_AS', 'Gem fil som:');
@define('STORE_IN_DIRECTORY', 'Gem i flgende bibliotek:');
@define('MEDIA_RENAME', 'Omdb denne fil');
@define('IMAGE_RESIZE', 'ndre strrelse p billede');
@define('MEDIA_DELETE', 'Slet denne fil');
@define('FILES_PER_PAGE', 'Filer per side');
@define('CLICK_FILE_TO_INSERT', 'Klik p filen du vil indstte:');
@define('SELECT_FILE', 'Vlg filen du vil indstte');
@define('MEDIA_FULLSIZE', 'Fuld strrelse');
@define('CALENDAR_BOW_DESC', 'Dagen i ugen der skal bruges som den frste dag i ugen. Standardvrdien er Mandag');
@define('SUPERUSER', 'Blog Administration');
@define('ALLOWS_YOU_BLAHBLAH', 'Placerer et link i sidebaren til din blog administration');
@define('CALENDAR', 'Kalender');
@define('SUPERUSER_OPEN_ADMIN', 'bn administration');
@define('SUPERUSER_OPEN_LOGIN', 'bn loginskrm');
@define('INVERT_SELECTIONS', 'Inverter valgte elementer');
@define('COMMENTS_DELETE_CONFIRM', 'Er du sikker p du vil slette de valgte kommentarer?');
@define('COMMENT_DELETE_CONFIRM', 'Er du sikker p du vil slette kommentar #%d, skrevet af %s?');
@define('DELETE_SELECTED_COMMENTS', 'Slet valgte kommentarer');
@define('VIEW_COMMENT', 'Vis kommentar');
@define('VIEW_ENTRY', 'Vis artikel');
@define('DELETE_FILE', 'Slettede filen ved navn <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Du er ved at slette <b>%s</b><br />Hvis du benytter denne fil i nogle af dine artikler, vil det resultere i dde links eller billeder<br />Er du sikker p du vil fortstte?<br /><br />');
@define('TRACKBACK_SENDING', 'Sender trackback til URI %s...');
@define('TRACKBACK_SENT', 'Trackback fuldfrt');
@define('TRACKBACK_FAILED', 'Trackback fejl: %s');
@define('TRACKBACK_NOT_FOUND', 'Ingen trackback URI fundet.');
@define('TRACKBACK_URI_MISMATCH', 'Den automastiske trackback URI passer ikke vores egen URI.');
@define('TRACKBACK_CHECKING', 'Checker <u>%s</u> for mulige trackbacks...');
@define('TRACKBACK_NO_DATA', 'Modstende side indeholdte inden data');
@define('TRACKBACK_SIZE', 'Modstende URI overskred den maximale filstrrelse p %s bytes.');
@define('VIEWMODE_THREADED', 'Skift til trdet visning');
@define('COMMENTS_VIEWMODE_THREADED', 'Trde');
@define('COMMENTS_VIEWMODE_LINEAR', 'Linear');
@define('DISPLAY_COMMENTS_AS', 'Vis kommentarer som');
@define('SIDEBAR_PLUGINS', 'Sidebarplugins');
@define('EVENT_PLUGINS', 'Hndelseplugins');
@define('ADD_MEDIA_BLAHBLAH', '<b>Tilfj en fil til dit mediearkiv:</b><p>Her kan du uploade mediafiler, eller f dem hentet fra et sted p nettet. Hvis du ikke har et passende billeder, <a href="http://images.google.com" target="_blank">prv at sg efter billeder p google</a> der passer til dine tanker, resultatet er ofte brugbart og sjovt :)</p><p><b>Vlg metode:</b></p><br/>');
@define('COMMENTS_FILTER_SHOW', 'Vis');
@define('COMMENTS_FILTER_ALL', 'Alle');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Kun godkendte');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Afventer godkendelse');
@define('RSS_IMPORT_BODYONLY', 'Placer al den importeret tekst ind i "artikel" delen, og ikke opdelt ind i "udvidet artikel" sektionen.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Vis hele artiklen, med udvidet del, inde i RSS feed');
@define('MT_DATA_FILE', 'MovableType data fil');
@define('FORCE', 'gennemtving');
@define('CREATE_AUTHOR', 'Opret forfatter \'%s\'.');
@define('CREATE_CATEGORY', 'Opret kategori \'%s\'.');
@define('MYSQL_REQUIRED', 'Du skal have MySQL udvidelsen installere frend du kan udfre denne handling.');
@define('COULDNT_CONNECT', 'Kunne ikke forbinde til MySQL database: %s.');
@define('COULDNT_SELECT_DB', 'Kunne ikke vlge database: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Kunne ikke finde bruger information: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Kunne ikke finde kategori information: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Kunne ikke finde artikel information: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Kunne ikke finde kommentar information: %s.');
@define('WEEK', 'Uge');
@define('WEEKS', 'Uger');
@define('MONTHS', 'Mnder');
@define('DAYS', 'Dage');
@define('ARCHIVE_FREQUENCY', 'Kalender frekvens');
@define('ARCHIVE_FREQUENCY_DESC', 'Angiver intervallet imellem hvert punkt p listen');
@define('ARCHIVE_COUNT', 'Antal punkter p listen');
@define('ARCHIVE_COUNT_DESC', 'Det totale antal af mneder, uger eller dage at vise');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Herunder er en liste over installerede plugins');
@define('SIDEBAR_PLUGIN', 'sidebar plugin');
@define('EVENT_PLUGIN', 'event plugin');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Klik her for at installere et nyt %s');
@define('VERSION', 'version');
@define('INSTALL', 'Installer');
@define('ALREADY_INSTALLED', 'Allerede installeret');
@define('SELECT_A_PLUGIN_TO_ADD', 'Vlg det plugin du nsker at installere');
@define('INSTALL_OFFSET', 'Server tidsforskydelse');
@define('STICKY_POSTINGS', 'Vedvarende artikler');
@define('INSTALL_FETCHLIMIT', 'Artikler p forsiden');
@define('INSTALL_FETCHLIMIT_DESC', 'Antallet af artikler at vise p hver side p forsiden');
@define('IMPORT_ENTRIES', 'Importer data');
@define('EXPORT_ENTRIES', 'Eksporter artikler');
@define('IMPORT_WELCOME', 'Velkommen til Serendipity importvrktj');
@define('IMPORT_WHAT_CAN', 'Her kan du importere artikler fra andre weblog software applikationer');
@define('IMPORT_SELECT', 'Vlg venligst det software du nsker at importere fra');
@define('IMPORT_PLEASE_ENTER', 'Indtast venligst de pkrvede data herunder');
@define('IMPORT_NOW', 'Importer nu!');
@define('IMPORT_STARTING', 'Starter import procedure...');
@define('IMPORT_FAILED', 'Importeringen fejlede');
@define('IMPORT_DONE', 'Importering gennemfrt');
@define('IMPORT_WEBLOG_APP', 'Weblog applikation');
@define('EXPORT_FEED', 'Eksporter fuldt RSS feed');
@define('STATUS', 'Status efter import');
@define('IMPORT_GENERIC_RSS', 'Almindelig RSS import');
@define('ACTIVATE_AUTODISCOVERY', 'Send Trackbacks til links fundet i artikler');
@define('WELCOME_TO_ADMIN', 'Velkommen til Serendipity Administrations suiten.');
@define('PLEASE_ENTER_CREDENTIALS', 'Indtast venligst dine adgangsoplysninger herunder.');
@define('ADMIN_FOOTER_POWERED_BY', 'Drives af Serendipity %s og PHP %s');
@define('INSTALL_USEGZIP', 'Benyt gzip komprimerede sider');
@define('INSTALL_USEGZIP_DESC', 'For at fremskynde levering af sider, kan vi komprimere siderne vi sender til den besgende, givet at hans browser understtter dette. Dette er anbefalet');
@define('INSTALL_SHOWFUTURE', 'Vis fremtidige artikler');
@define('INSTALL_SHOWFUTURE_DESC', 'Hvis aktiveret, dette vil vise alle fremtidige artikler p din blog. Som standard skjules disse artikler og vises frst nr udgivelsesdatoen er net.');
@define('INSTALL_DBPERSISTENT', 'Brug vedvarende forbindelser');
@define('INSTALL_DBPERSISTENT_DESC', 'Aktiver brug af vedvarende database forbindelser, ls mere <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">her</a>. Dette anbefales normalt ikke');
@define('NO_IMAGES_FOUND', 'Ingen billeder fundet');
@define('PERSONAL_SETTINGS', 'Personlige indstillinger');
@define('REFERER', 'Henvisende side');
@define('NOT_FOUND', 'Ikke fundet');
@define('NOT_WRITABLE', 'Ikke skrivbar');
@define('WRITABLE', 'Skrivbar');
@define('PROBLEM_DIAGNOSTIC', 'Grundet en problematisk diagnose, kan du ikke fortstte med installationen frend ovenstende fejl er rettet');
@define('SELECT_INSTALLATION_TYPE', 'Vlg hvilken installationstype du vil benytte');
@define('WELCOME_TO_INSTALLATION', 'Velkommen til Serendipity Installationen');
@define('FIRST_WE_TAKE_A_LOOK', 'Frst kigger vi p dit nuvrende setup og vil forsge at diagnosere eventuelle kompatibilitetsproblemer');
@define('ERRORS_ARE_DISPLAYED_IN', 'Fejl er vist som %s, anbefalinger som %s og succes som %s');
@define('RED', 'rd');
@define('YELLOW', 'gul');
@define('GREEN', 'grn');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s fr-installations report');
@define('RECOMMENDED', 'Anbefalet');
@define('ACTUAL', 'Faktisk');
@define('PHPINI_CONFIGURATION', 'php.ini konfiguration');
@define('PHP_INSTALLATION', 'PHP installation');
@define('THEY_DO', 'det gr de');
@define('THEY_DONT', 'det fr de ikke');
@define('SIMPLE_INSTALLATION', 'Simpel installation');
@define('EXPERT_INSTALLATION', 'Expert installation');
@define('COMPLETE_INSTALLATION', 'Fuldfr installation');
@define('WONT_INSTALL_DB_AGAIN', 'Installerer ikke database igen');
@define('CHECK_DATABASE_EXISTS', 'Undersger om databasen og tabllerne allerede findes');
@define('CREATING_PRIMARY_AUTHOR', 'Opretter primr forfatter \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Stter standard skabelon');
@define('INSTALLING_DEFAULT_PLUGINS', 'Installerer standard plugins');
@define('SERENDIPITY_INSTALLED', 'Serendipity er nu installeret');
@define('VISIT_BLOG_HERE', 'Besg din nye blog her');
@define('THANK_YOU_FOR_CHOOSING', 'Tak fordi du valgte Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'En fejl blev fundet under installationen');
@define('OPERATING_SYSTEM', 'Operativsystem');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('IMAGE_ROTATE_LEFT', 'Roter billede 90 grader imod uret');
@define('IMAGE_ROTATE_RIGHT', 'Roter billede 90 grader med uret');
@define('TEMPLATE_SET', '\'%s\' er blevet sat som din aktive skabelon');
@define('SEARCH_ERROR', 'Sgefunktionen fungere ikke som forventet. Besked til administratoren: Dette sker muligvis pga. en manglende index key i databasen. P MySQL systemer skal din bruger have rettigheder til at udfre denne query: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Den specifikke fejl returneret af databasen, var: <pre>%s</pre>');
@define('EDIT_THIS_CAT', ' Redigerer "%s"');
@define('CATEGORY_REMAINING', 'Slet denne kategori og flyt dens artikler ind i denne kategori');
@define('CATEGORY_INDEX', 'Nedenunder er en liste over kategorier der er tilgngelige for dine artikler');
@define('NO_CATEGORIES', 'Ingen kategorier');
@define('RESET_DATE', 'Reset dato');
@define('RESET_DATE_DESC', 'Klik her for at resette datoen til den nuvrende tid');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Rettigheder kan gives ved at krer flgende shell kommando: `<em>%s</em>` p det fejlede bibliotek, eller ved at stte det vha. et FTP program');
@define('WARNING_TEMPLATE_DEPRECATED', 'Advarsel: Din nuvrende skabelon bruger en forldet skabelon metode, vi anbefaler du opgraderer, hvis muligt');
@define('ENTRY_PUBLISHED_FUTURE', 'Denne artikel er endnu ikke udgivet.');
@define('ENTRIES_BY', 'Artikler skrevet af %s');
@define('PREVIOUS', 'Forrige');
@define('NEXT', 'Nste');
@define('APPROVE', 'Godkend');
@define('DO_MARKUP_DESCRIPTION', 'Tilfj markup-transformationer p teksten (smilies, shortcut markups via *, /, _, ...). Hvis du slr dette fra vil al HTML-kode i teksten blive bibeholdt.');
@define('CATEGORY_ALREADY_EXIST', 'En kategori med navnet "%s" findes allerede');
@define('IMPORT_NOTES', 'Note:');
@define('ERROR_FILE_FORBIDDEN', 'Det er ikke tilladt at uploade filer med aktivt indhold');
@define('ADMIN', 'Administration'); // Re-Translate
@define('ADMIN_FRONTPAGE', 'Forside');
@define('QUOTE', 'Citer');
@define('IFRAME_SAVE', 'Serendipity gemmer nu din artikel, sender trackbacks og udfrer mulige XML-RPC calls. Dette kan tage noget tid..');
@define('IFRAME_SAVE_DRAFT', 'Et udkast af denne artikel er blevet gemt');
@define('IFRAME_PREVIEW', 'Serendipity opretter nu et preview af din artikel...');
@define('IFRAME_WARNING', 'Din browser understtter ikke iframes. bn serendipity_config.inc.php og st $serendipity[\'use_iframe\'] til FALSE.');
@define('NONE', 'ingen');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Standard indstillinger for nye artikler');
@define('UPGRADE', 'Opgrader');
@define('UPGRADE_TO_VERSION', 'Opgrader til v%s');
@define('DELETE_DIRECTORY', 'Slet mappe');
@define('DELETE_DIRECTORY_DESC', 'Du er ved at slette indholdet af en mappe der indeholder multimedia filer, muligvis filer brugt i dine artikler.');
@define('FORCE_DELETE', 'Slet ALLE filer i denne mappe, inklusiv dem ikke kendt af Serendipity');
@define('CREATE_DIRECTORY', 'Opret mappe');
@define('CREATE_NEW_DIRECTORY', 'Opret ny mappe');
@define('CREATE_DIRECTORY_DESC', 'Her kan du oprette en ny mappe til at placere dine multimedia filer i. Vlg navnet p din nye mappe, og vlg en passende mappe at oprette den i.');
@define('BASE_DIRECTORY', 'Rodmappe');
@define('USERLEVEL_EDITOR_DESC', 'Standard editor');
@define('USERLEVEL_CHIEF_DESC', 'Chefeditor');
@define('USERLEVEL_ADMIN_DESC', 'Administrator');
@define('USERCONF_USERLEVEL', 'Adgangsniveau');
@define('USERCONF_USERLEVEL_DESC', 'Dette niveau er brugt til at bestemme hvilken type adgang brugeren har til bloggen');
@define('USER_SELF_INFO', 'Logget ind som %s (%s)');
@define('ADMIN_ENTRIES', 'Artikler');
@define('RECHECK_INSTALLATION', 'Check installation igen');
@define('IMAGICK_EXEC_ERROR', 'Kunne ikke eksekvere: "%s", fejl: %s, return var: %d');
@define('INSTALL_OFFSET_DESC', 'Indtast antallet af timer mellem tiden p din webserver (%clock%) og din fortrukne tidszone');
@define('UNMET_REQUIREMENTS', 'Uopfyldt krav: %s');
@define('CHARSET', 'Karakterst');
@define('AUTOLANG', 'Brug som standard, brugerens browser sprog');
@define('AUTOLANG_DESC', 'Hvis aktiveret, vil brugerens browsersprog benyttes til at finde det viste sprog i dine artikler og interface.');
@define('INSTALL_AUTODETECT_URL', 'Autoudregn anvendt HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', 'Hvis denne er sat til "ja", vil Serendipity sikre at den HTTP Host der anvendes af dine besgende, anvendes som din BaseURL indstilling. Aktiverer du dette, kan du bruge flere domnenavne p samme Serendipity Blog.');
@define('CONVERT_HTMLENTITIES', 'Prv at konvertere HTML entities automatisk?');
@define('EMPTY_SETTING', 'Du angav ikke en gyldig vrdi for "%s"!');
@define('USERCONF_REALNAME', 'Rigtigt navn');
@define('USERCONF_REALNAME_DESC', 'Det fulde navn p forfatteren. Dette er navnet set af lserne');
@define('HOTLINK_DONE', 'Fil blev hotlinked.<br />Frdig.');
@define('ENTER_MEDIA_URL_METHOD', 'Afhentningsmetode:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Bemrk: Hvis du vlger at hotlinke til en server, br du sikre dig tilladelse til at gre dette, eller vre ejeren af serveren. Hotlink gr det muligt at bruge eksterne billeder, uden at gemme dem lokalt.');
@define('MEDIA_HOTLINKED', 'hotlinked');
@define('FETCH_METHOD_IMAGE', 'Hent billede til din server');
@define('FETCH_METHOD_HOTLINK', 'Hotlink til server');
@define('DELETE_HOTLINK_FILE', 'Slet den hotlinkede fil ved navn <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Vis E-Mail adresser?');
@define('IMAGE_MORE_INPUT', 'Tilfj flere billeder');
@define('BACKEND_TITLE', 'Yderligere information p plugin konfigurations siden');
@define('BACKEND_TITLE_FOR_NUGGET', 'Her kan du indtaste en tekst som vises p plugin konfigurations siden, sammen med beskrivelsen af din HTML Nugget. Har du flere HTML Nuggets med tom titel kan dette hjlpe med at genkende dem fra hinanden.');
@define('CATEGORIES_ALLOW_SELECT', 'Tillad brugere at vise flere kategorier samtidig?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Hvis denne mulighed aktiveres vises en checkboks ud for hver kategori i denne sidebar. Brugere kan afkrydse disse bokse og derefter se indlg afhngig af deres valg.');
@define('PAGE_BROWSE_PLUGINS', 'Side %s af %s, i alt %s plugins.');
@define('INSTALL_CAT_PERMALINKS', 'Permalinks');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Angiver forskellige URL mnstre som definerer permanente links i din blog. Det anbefales at bruge standardvrdierne; hvis ikke, br du bruge %id% vrdien hvor muligt for at forhindre at Serendipity skal sl URL\'en op i databasen.');
@define('INSTALL_PERMALINK', 'Permalink URL struktur');
@define('INSTALL_PERMALINK_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor artiklerne bliver tilgngelige. Du kan bruge variablene %id%, %title%, %day%, %month%, %year% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_AUTHOR', 'Permalink forfatter URL struktur');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor artikler fra bestemte forfattere bliver tilgngelige. Du kan bruge variablene %id%, %realname%, %username%, %email% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_CATEGORY', 'Permalink kategori URL struktur');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor artikler fra bestemte kategorier bliver tilgngelige. Du kan anvende de variable %id%, %name%, %parentname%, %description% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permalink RSS-Feed kategori URL struktur');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor RSS-feeds fra bestemte kategorier bliver tilgngelige. Du kan anvende de variable %id%, %name%, %description% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Sti til arkiver');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Sti til arkiv');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Sti til kategorier');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Sti til  afmeldings kommentarer');
@define('INSTALL_PERMALINK_DELETEPATH', 'Sti til sletning af kommentarer');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Sti til godkendelse af kommentarer');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Sti til RSS feeds');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Sti til et plugin');
@define('INSTALL_PERMALINK_ADMINPATH', 'Sti til admin');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Sti til sgning');
@define('INSTALL_CAL', 'Kalendar type');
@define('INSTALL_CAL_DESC', 'Vlg dit kalenderformat');
@define('REPLY', 'Svar');
@define('USERCONF_GROUPS', 'Gruppe medlemsskab');
@define('USERCONF_GROUPS_DESC', 'Brugeren er medlem af flgende grupper. Det er muligt at vre medlem af flere grupper.');
@define('MANAGE_GROUPS', 'Hndter grupper');
@define('DELETED_GROUP', 'Gruppe #%d %s slettet.');
@define('CREATED_GROUP', 'En nye gruppe %s er blevet oprettet');
@define('MODIFIED_GROUP', 'Egenskaberne for gruppen %s er blevet ndret');
@define('GROUP', 'Group');
@define('CREATE_NEW_GROUP', 'Opret ny gruppe');
@define('DELETE_GROUP', 'Slet gruppe  #%d %s. Er du sikker?');
@define('USERLEVEL_OBSOLETE', 'BEMRK: Brugerniveau indstillingen anvendes nu kun til bagud kompatibilitet. Bruger privilegier angives nu ved hjlp af gruppe medlemskaber!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'ID p det feed du nsker at offentliggre');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner billede');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Navn p billede der skal vises (ingenting giver en tller), billedet skal eksistere hos  feedburner.com, f.eks.: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner titel');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Eventuel titel der skal vises ved billedet');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner billedtekst');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Eventuel \'hover\' tekst til billedet');
@define('SEARCH_TOO_SHORT', 'Din sgestreng skal vre lngere end 3 tegn. Du kan stte * efter dit sgeord for at sge p kortere dele af ord (f.eks. s9y*)');
@define('INSTALL_DBPORT', 'Database port');
@define('INSTALL_DBPORT_DESC', 'Denne port anvendes til at forbinde til din databaseserver');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Frontend: Eksterne tjenester');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Frontend: Features');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Frontend: Fulde moduler');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Frontend: Views');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Frontend: Artikel relateret');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Backend: Editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Backend: Brugerhndtering');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Backend: Meta information');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Backend: Skabeloner');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Backend: Features');
@define('PLUGIN_GROUP_IMAGES', 'Billeder');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Markup');
@define('PLUGIN_GROUP_STATISTICS', 'Statistik');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Adgang til personlig konfiguration');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: ndre brugerniveauer');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: ndre "forbyd oprettelse af artikler"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: ndre rettighed til at offentliggre artikler');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Adgang til system konfiguration');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Adgang til blog-specifik konfiguration');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrer artikler');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administrer andres artikler');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Importer artikler');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrer kategorier');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrer andre brugeres kategorier');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Slet kategorier');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrer brugere');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Slet brugere');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: ndre brugerniveau');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrer brugere i din(e) gruppe(r)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrer bruger der ikke er i din(e) gruppe(r)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Opret nye brugere');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrer grupper');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrer plugins');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrer andre brugeres plugins');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrer media filer');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrer media biblioteker');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Tilfj nye media filer');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Slet media filer');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrer andres media filer');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Vis media filer');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Opdater minibilleder');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrer kommentarer');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrer skabeloner');
@define('INSTALL_BLOG_EMAIL', 'Bloggens emailadresse');
@define('INSTALL_BLOG_EMAIL_DESC', 'Her angives emailadressen som anvendes i \'fra\' feltet p udgende email fra bloggen. Vr opmrksom p at mange mailservere afviser email med ukendt eller ikke eksisterende emailadresse i \'fra\' feltet.');
@define('CATEGORIES_PARENT_BASE', 'Vis kun kategorier herunder...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Du kan vlge en forlder kategori, s kun kategorierne herunder vises.');
@define('CATEGORIES_HIDE_PARALLEL', 'Skjul kategorier som ikke er en del af kategoritret');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Hvis du nsker at skjule kategorier som er del af et andet kategoritr skal du vlge \'Ja\' her. Denne feature giver mest mening i en flerbruger blog installation, som anvender "Properties/Tempaltes of categories" pluginet.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Vis andre brugeres media filer');
@define('CHARSET_NATIVE', 'Native');
@define('INSTALL_CHARSET', 'Karakterst valg');
@define('INSTALL_CHARSET_DESC', 'Her kan du vlge mellem UTF-8 eller \'native\' (lokalt,  f.eks. ISO-8859-1) karakterst. Nogle sprog har kun UTF-8 oversttelsen, s at stte valget til \'native\' vil ikke have nogen effekt. UTF-8 anbefales til nyinstallationer. Lad vre med at ndre denne indstilling hvis du allerede har lavet artikler med special karakterer - det kan medfre dine artikler vises forkert. Ls mere om alt dette p <a href="http://www.s9y.org/index.php?node=46">http://www.s9y.org/index.php?node=46</a>');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Aktiver Plugin API hook');
@define('CALENDAR_EXTEVENT_DESC', 'Hvis aktiveret kan plugins "hgte" sig p kalenderen og fremhve deres egne events. Aktiver kun hvis du har installeret plugins der krver dette, da det forringer performance.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'Serendipity\'s XML-RPC API interface leveres ikke lngere sammen med Serendipity p grund af gentagne sikkerhedsproblemer med dette API. Du er derfor ndt til at installere XML-RPC pluginet for at kunne bruge XML-RPC API. URL\'en i dine programmer ndres IKKE - s snart pluginet er installeret vil du igen vre istand til at bruge dette API.');
@define('PERM_READ', 'Lse rettighed');
@define('PERM_WRITE', 'Skrive rettighed');

@define('PERM_DENIED', 'Permission denied.');
@define('INSTALL_ACL', 'Anvend lserettigheder for kategorier');
@define('INSTALL_ACL_DESC', 'Hvis aktiveret anvendes grupperettigheder for brugere der er logget ind. I modsat fald anvendes lserettigheder for kategorier ikke, men din blog bliver til gengld lidt hurtigere. S har du ikke brug for multibruger lserettigheder  i din blog br du vlge \'nej\' her.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Konfigurations syntax forkert for indstilling "%s". Skal bruge indhold af typen "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Nuvrende kodeord');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Hvis du ndrer kodeord i feltet herover skal du indtaste dit nuvrende kodeord her.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Du indtastede ikke det rigtige nuvrende kodeord, og kan derfor ikke ndre kodeord, din ndring blev ikke gemt.');
@define('ERROR_XSRF', 'Your browser did not sent a valid HTTP-Referrer string. This may have either been caused by a misconfigured browser/proxy or by a Cross Site Request Forgery (XSRF) aimed at you. The action you requested could not be completed.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor RSS-feeds fra bestemte forfattere bliver tilgngelige. Du kan anvende de variable vrdier %id%, %realname%, %username%, %email% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed forfatter URL struktur');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Sti til forfattere');
@define('AUTHORS', 'Forfattere');
@define('AUTHORS_ALLOW_SELECT', 'Tillad besgende at vise flere forfattere samtidig?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Hvis aktiveret vil der vises en checkboks ud for hver forfatter i sidebaren. Brugere kan s afkrydse hvilke forfatteres artikler der skal vises.');
@define('AUTHOR_PLUGIN_DESC', 'Vis en liste over forfattere');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Aktiver Smarty-skabeloner?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Aktiveres denne indstilling, vil der anvendes Smarty skabelon features i opbygningen af kategorilisten, du har mulighed for at ndre layout for listen i "plugin_categories.tpl" skabelon filen. Bemrk, denne indstilling koster performance, s har du ikke behov for den, s lad vre med at aktivere den.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Vis antal artikler pr. kategori?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Vis antal artikler ved siden af forfatternavn?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Hvis aktiv, vises antallet af artikler forfatteren har skrevet i paranteser ved siden af forfatternavnet.');
@define('CUSTOM_ADMIN_INTERFACE', 'Tilpasset administrator interface');
 
@define('COMMENT_NOT_ADDED', 'Din kommentar kunne ikke tilfjes af en af flgende grunde: kommentarer til denne artikel er blevet deaktiveret, du indtastede forkerte data, eller din kommentar blev fanget af antispam beskyttelsen');
@define('INSTALL_TRACKREF', 'Visning af referencer?');
@define('INSTALL_TRACKREF_DESC', 'Aktiverer du reference visning, vil du kunne se hvilke sites der henviser til dine artikler. Dette bliver tit misbrugt til spam.');
@define('CATEGORIES_HIDE_PARENT', 'Skjul den valgte overkategori?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Hvis du begrnser visningen af kategorier til en specifik kategori, vil du som standard se overkategorien i listen. Deaktiveres denne indstilling vises overkategorien ikke.');
@define('WARNING_NO_GROUPS_SELECTED', 'Advarsel: Du har ikke valgt noget gruppemedlemskab. Da dette ville logge dig ud af brugergruppeadministrationen, er dine ndringer derfor ikke gemt.');
@define('INSTALL_RSSFETCHLIMIT', 'Artikler i feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Antallet af artikler der skal vises p hver side i RSS feeds.');
@define('INSTAL_DB_UTF8', 'Brug database karakterst-oversttelse');
@define('INSTAL_DB_UTF8_DESC', 'Udfrer MySQL kommandoen "SET NAMES .." for at angive det krvede karakterst. Deaktiver hvis du ser underlige karakterer i din blog.');
@define('ONTHEFLYSYNCH', 'Automatisk medie synkronisering');
@define('ONTHEFLYSYNCH_DESC', 'Hvis aktiv, vil  Serendipity sammenligne medie databasen med filerne der er gemt p serveren og synkronisere disse.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'Brugernavn skal indtastes.');
@define('FURTHER_LINKS', 'Further Links');
@define('FURTHER_LINKS_S9Y', 'Serendipity hjemmeside');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity dokumentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Officiel blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Fora');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Kommentar slettet)');

@define('CURRENT_AUTHOR', 'Aktuel forfatter');

@define('WORD_NEW', 'Ny');
@define('SHOW_MEDIA_TOOLBAR', 'Vis vrktjslinie i medievlger popup?');
@define('MEDIA_KEYWORDS', 'Medie ngleord');
@define('MEDIA_KEYWORDS_DESC', 'Indtast en ";" adskilt liste af ord du vil prdefinere som ngleord for medie filer.');
@define('MEDIA_EXIF', 'Importer EXIF/JPEG billeddata');
@define('MEDIA_EXIF_DESC', 'Hvis aktiv, vil EXIF/JPEG metadata blive indlst og gemt i databasen for senere at kunne vises i medie galleriet.');
@define('MEDIA_PROP', 'Medie egenskaber');


@define('GO_ADD_PROPERTIES', 'Go & enter properties');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Kort kommentar');
@define('MEDIA_PROPERTY_COMMENT2', 'Lang kommentar');
@define('MEDIA_PROPERTY_TITLE', 'Titel');
@define('MEDIA_PROP_DESC', 'Indtast ";" adskilt liste af felter/egenskaber du vil definere for hver mediefil. ');
@define('MEDIA_PROP_MULTIDESC', '(Du kan tilfje ":MULTI" efter ethvert felt for at angive dette felt indeholder en lang tekst i stedet for blot nogle karakterer)');

@define('STYLE_OPTIONS_NONE', 'Denne skabelon/stil har ikke nogen specifikke indstillinger. Ls den tekniske dokumentation p www.s9y.org, punktet "Configuration of Theme options", for at se hvordan din skabelon kan anvende indstillinger.');
@define('STYLE_OPTIONS', 'Tema/stil indstillinger');

@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');

@define('SYNDICATION_RFC2616', 'Aktiver RSS-feeds der overholder RFC2616');
@define('SYNDICATION_RFC2616_DESC', 'Hvis IKKE RFC2616 overholdes vil alle foresprgsler til Serendipity returnere artikler ndret siden  tidspunktet for sidste foresprgsel. Dvs \'nej\' medfrer at dine besgende fr alle artikler siden sidst. P den anden side, nogle RSS aggregatorer som f.eks. \'Planet\' opfrer sig underligt med denne indstilling da den jo ikke overholder RFC2616. Ls eventuelt mere om problemet her <a href="<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>"><a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a></a>');
@define('MEDIA_PROPERTY_DATE', 'Tilhrende dato');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Spilletid');
@define('FILENAME_REASSIGNED', 'Nyt filnavn automagisk tildelt: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. fil upload strrelse');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Angiv maximal filstrrelse for uploadede filer. Denne indstilling kan overskrives af en server indstilling i PHP.ini: upload_max_filesize, post_max_size, max_input_time har alle hjere prioritet end denne indstilling. Indtaster du ikke noget, anvendes server indstillingerne.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Fejl: Du kan ikke uploade filer strre end %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. bredde for uploadede billeder');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Indtast den maximale bredde i pixels, for uploadede billeder.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. hjde for uploadede billeder');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Indtast den maximale hjde i pixels, for uploadede billeder.');
@define('MEDIA_UPLOAD_DIMERROR', 'Fejl: Du kan ikke uploade billeder der er strre end %s x %s pixels!');

@define('MEDIA_TARGET', 'Target for this link');
@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, tilpasset strrelse)');
@define('MEDIA_ENTRY', 'Selvstndig artikel');
@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Tillad dynamiske billedstrrelser?');
@define('MEDIA_DYN_RESIZE_DESC', 'Hvis aktiveret, kan medievlgeren returnere billeder i vilkrlige strrelser, styret af en GET variabel, billederne caches og kan derfor generere mange filer.');

@define('MEDIA_DIRECTORY_MOVED', 'Bibliotek og filer blev flyttet til %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Bibliotek og filer kunne ikke flyttes til %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'P IKKE-MySQL databaser, understttes iteration gennem artikler for at opdatere stier til biblioteker ikke. Du bliver ndt til manuelt at redigere dine artikler og rette stierne, er dette for besvrligt kan du flytte dit bibliotek tilbage til den gamle placering.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Stien til det flyttede bibliotek er opdateret i %s artikler.');
@define('PLUGIN_ACTIVE', 'Aktiv');
@define('PLUGIN_INACTIVE', 'Inaktiv');
@define('PREFERENCE_USE_JS', 'Aktiver advanceret JS brug?');
@define('PREFERENCE_USE_JS_DESC', 'Hvis aktiveret, vil der blive anvendt advancerede Javascript funktioner for at give en forbedret brugeroplevelse, f.eks. i plugin konfigurationen, hvor drag & drop omrokering af plugins bliver mulig.');

@define('PREFERENCE_USE_JS_WARNING', '(Denne side anvender advanceret JavaScript. Fr du funktionalitetsproblemer, s sl advanceret JS brug fra i dine personlige indstillinger, eller deaktiver Javascript i din browser)');

@define('INSTALL_PERMALINK_COMMENTSPATH', 'Sti til kommentarer');
@define('PERM_SET_CHILD', 'St de samme rettigheder p alle underliggende biblioteker');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Aktiver plugin adgangskontrol for grupper?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Mulighed for at bestemme hvilke grupper der m anvende hvilke plugins.');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
@define('SET_TO_MODERATED', 'Moderate');
@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
@define('CENTER', 'center');
@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');

@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
@define('BADTOKEN', 'Invalid Moderation Link'); 

@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
@define('PLUGIN_DOCUMENTATION', 'Documentation');
@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD', '(If you enter an absolute URL with http://... here, this URL will be used as the redirection target in case you have enabled the "Force" option for FeedBurner. Note that this can also be a URL independent to FeedBurner. For new Google FeedBurner feeds, you need to enter http://feeds2.feedburner.com/yourfeedname here)');

@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD2', 'If you set this option to "Force" you can forward the RSS feed to any webservice, not only FeedBurner. Look at the option "Feedburner ID" below to enter an absolute URL)');
@define('COMMENTS_FILTER_NEED_CONFIRM', 'Pending user confirmation');
@define('NOT_WRITABLE_SPARTACUS', ' (Only required when you plan to use Spartacus plugin for remote plugin download)');
@define('MEDIA_ALT', 'ALT-Attribute (depiction or short description)');
@define('MEDIA_PROPERTY_ALT', 'Depiction (summary for ALT-Attribute)');

@define('MEDIA_TITLE', 'TITLE-Attribute (will be displayed on mouse over)');

@define('QUICKSEARCH_SORT', 'How should search-results be sorted?');

@define('QUICKSEARCH_SORT_RELEVANCE', 'Relevance');

